@@ -16,7 +16,7 @@ use Module::Metadata;
 use Scalar::Util ();
 use Test::More 0.88;
 
-our $VERSION = '0.000_915';
+our $VERSION = '0.000_916';
 
 our @EXPORT_OK = qw{ all_prereq_ok file_prereq_ok prereq_ok };
 our %EXPORT_TAGS = (
@@ -107,6 +107,15 @@ sub new {
 	    join ', ', @dup;
     }
 
+    # FIXME the following is because we don't scan Makefile.PL and/or
+    # Build.PL
+    -e 'Makefile'
+	and $has{'ExtUtils::MakeMaker'}
+	and push @{ $arg{uses} }, 'ExtUtils::MakeMaker';
+    -e 'Build'
+	and $has{'Module::Build'}
+	and push @{ $arg{uses} }, 'Module::Build';
+
     delete $arg{accept};
     delete $arg{_meta_file};
     delete $arg{path_type};
